diff --git a/asdf.asd b/asdf.asd
index 25e1d9b51d16799887b4fc78f18beea63504cefc..bb590c5e106fc119694c7afb6c21b23dac2529c5 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.18" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.19" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/doc/asdf.texinfo b/doc/asdf.texinfo
index b75551b8e728934ef8a891365f5a7f453a46c956..b4e1908972d7150aa7ab863e528c022fe6348301 100644
--- a/doc/asdf.texinfo
+++ b/doc/asdf.texinfo
@@ -1460,7 +1460,7 @@ both of them apply to systems that are dependencies and were already compiled.
 
 To see what @code{operate} would do, you can use:
 @example
-(asdf::traverse (make-instance @var{operation-class} {@var{initargs} ...}) (find-system @var{system-name}))
+(asdf::traverse (make-instance operation-class initargs ...) (find-system system-name))
 @end example
 
 @end deffn
@@ -1578,8 +1578,8 @@ On your build platform, you run something like that:
 And on your delivery platform, a form like this is evaluated
 in a prologue or at some point before you save your image:
 @example
-@code{(defsystem @var{:mysystem} :class :precompiled-system
-        :fasl @var{(some expression that will evaluate to a pathname)})}
+(defsystem :mysystem :class :precompiled-system
+    :fasl (some expression that will evaluate to a pathname))
 @end example
 
 Of course, @emph{before} you define such systems,
diff --git a/asdf.lisp b/asdf.lisp
index 2091ca87e7845fb05b92b69d09f6173a903d4e36..5fb35d347cd5f6211a3771de79c81d27be48752b 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.18: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.18")
+         (asdf-version "2.26.19")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -2329,11 +2329,11 @@ PREVIOUS-TIME when not null is the time at which the PREVIOUS system was loaded.
     ;; Warn if some files are missing:
     ;; either our model is wrong or some other process is messing with our files.
     (when (and just-done (not all-present))
-      (warn "~A completed without~*~@[ its input file~:p~{ ~S~}~]~
-             ~@[ or~]~*~@[ its output file~:p~*~{ ~S~}~]"
+      (warn "~A completed without ~:[~*~;~*its input file~:p~2:*~{ ~S~}~*~]~
+             ~:[~; or~] ~:[~*~;~*its output file~:p~2:*~{ ~S~}~*~]"
             (operation-description o c)
-            (length missing-in) missing-in (and missing-in missing-out)
-            (length missing-out) missing-out))
+            missing-in (length missing-in) (and missing-in missing-out)
+            missing-out (length missing-out)))
     ;; Note that we use stamp<= instead of stamp< to play nice with generated files.
     ;; Any race condition is intrinsic to the limited timestamp resolution.
     (if (or just-done ;; The done-stamp is valid: if we're just done, or
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.18: Another System Definition Facility.
+;;; This is ASDF 2.26.19: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: